pub enum Commands {
Show 21 variants
Init {
non_interactive: bool,
main_branch: Option<String>,
remote: Option<String>,
},
Info {
edit: bool,
},
Update,
Commit {
type: Option<String>,
scope: Option<String>,
message: Option<String>,
breaking: bool,
breaking_description: Option<String>,
tag: Option<String>,
no_verify: bool,
issue: Option<String>,
body: Option<String>,
message_file: Option<String>,
body_file: Option<String>,
include_projects: bool,
},
Branch {
type: Option<String>,
name: Option<String>,
issue: Option<String>,
from_commit: Option<String>,
},
Complete {
type: Option<String>,
name: Option<String>,
},
Sync,
Radar,
Status,
CurrentBranch,
CheckBranches,
GenerateManPage,
Completion {
shell: Shell,
},
Changelog {
from: Option<String>,
to: Option<String>,
unreleased: bool,
},
Config {
get_dod: bool,
},
HeadSha,
Undo {
sha: String,
no_push: bool,
},
Note {
message: Option<String>,
show: bool,
},
Task(TaskAction),
Recover {
selector: Option<String>,
list: bool,
},
Review {
sha: Option<String>,
trigger: bool,
digest: bool,
approve: Option<String>,
concern: Option<String>,
dismiss: Option<String>,
message: Option<String>,
since: String,
reviewers: Option<Vec<String>>,
},
}Variants
Init
Initialises the repository for Trunk-Based Development.
Fields
Info
Shows the current tbdflow configuration.
Update
Checks for a new version of tbdflow and updates it if available.
Commit
Commits changes to the current branch or ‘main’ if no branch is checked out.
Fields
message_file: Option<String>Read the commit subject from a file (‘-’ for stdin). Avoids shell escaping. Conflicts with –message.
Branch
Creates and pushes a new short-lived branch.
Fields
Complete
Merges a short-lived branch into ‘main’ and deletes it.
Fields
Sync
Syncs with the remote, shows recent history, and checks for stale branches. When ci_check is enabled, checks trunk CI status before pulling.
Radar
Scans active remote branches for overlapping work that may cause merge conflicts.
Status
Shows the current git status.
CurrentBranch
Shows the current git branch name.
CheckBranches
Checks for stale branches (older than 1 day).
GenerateManPage
Generates a man page for the CLI.
Completion
Generates shell completion scripts.
Changelog
Generates a changelog from Conventional Commits.
Fields
Config
Internal commands for configuration.
HeadSha
Prints the short SHA of the current HEAD commit.
Undo
Reverts a commit on the trunk by its SHA. The panic button for trunk-based development.
Fields
Note
Logs an intent note (breadcrumb) during development. Notes are captured in a local .tbdflow-intent.json and included in the next commit message as an Intent Log.
Fields
Task(TaskAction)
Manages the current task context for the intent log.
Recover
Recovers a WIP snapshot from the safety log. Snapshots are captured automatically during notes and syncs.
Fields
Review
Manages non-blocking post-commit reviews for trunk-based development.