Enums
Functions
- add_all
- Add all changes to the staging area.
- add_
excluding_ projects - add_
remote - Add a new remote repository to the current Git repository.
git remote add origin
- branch_
exists_ locally - Check if the branch exists locally.
- checkout_
main - Check out the main branch.
- commit
- Commit changes with a message.
- create_
branch - Create a new branch from the current HEAD or a specified point.
- create_
tag - Create a new tag with a message at a specific commit hash.
- delete_
local_ branch - Delete a local short-lived branch.
- delete_
remote_ branch - Delete a remote branch.
- fetch_
origin - Fetch the latest changes from the origin remote.
- find_
branch - Find a branch by name
- get_
commit_ history - Get the commit history in a specific range.
- get_
current_ branch - Get the current branch name.
- get_
git_ root - Find the root directory of the Git repository and return its path.
- get_
head_ commit_ hash - Get the hash of the current HEAD commit.
- get_
latest_ tag - Get the latest tag in the repository. This returns the most recent tag, which is useful for versioning.
- get_
remote_ url - Get the remote URL of the repository.
- get_
stale_ branches - Check for stale branches in the repository.
- get_
status_ full - get_
status_ short - has_
staged_ changes - Checks if there are any changes in the staging area.
- init_
git_ repository - Initialise a new Git repository in the current directory.
- is_
git_ repository - Check if the current dir is a valid Git repository.
- is_
working_ directory_ clean - Checks if the git working directory is clean.
- log_
graph - Show recent commits in the repository, 15 by default.
- merge_
branch - Merge the current branch with another branch.
- pull_
latest_ with_ rebase - Pull the latest changes with rebase.
- push
- Push changes to the remote repository.
- push_
set_ upstream - Push a new branch to the remote repository and set it as upstream. This is useful for new branches that have not been pushed before.
- push_
tags - Push all tags to the remote repository.
- rebase_
onto_ main - Rebase the current branch onto the main branch.
- remote_
branch_ exists - Check if a remote branch exists.
This checks if a branch exists on the remote repository (e.g.
origin). - status
- Show the current status of the repository.
- status_
excluding_ projects - Show the current status of the repository, excluding changes in specified project directories.
- status_
for_ path - tag_
exists - Check if the tag exists in the repository.